Functions
- build_
node_ module_ import_ paths - Build all ancestor paths from the main module path, to be used as
starting points for node_modules scanning.
Mirrors
ModuleStateBuilder.buildNodeModuleImportPaths. - build_
node_ module_ paths - Recursively discover all node module paths starting from the given import paths.
Mirrors
ModuleStateBuilder.buildNodeModulePaths.