Module node_modules

Module node_modules 

Functions

build_node_module_import_paths
Build all ancestor paths from the main module path, to be used as starting points for node_modules scanning. Mirrors ModuleStateBuilder.buildNodeModuleImportPaths.
build_node_module_paths
Recursively discover all node module paths starting from the given import paths. Mirrors ModuleStateBuilder.buildNodeModulePaths.